[![Python tests](https://github.com/luissian/s-rna-tools/actions/workflows/python_lint.yml/badge.svg)](https://github.com/luissian/s-rna-tools/actions/workflows/python_lint.yml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![install with Bioconda](https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg)](https://bioconda.github.io/recipes/nf-core/README.html)
[![install with PyPI](https://img.shields.io/badge/install%20with-PyPI-blue.svg)](https://pypi.org/project/nf-core/)
# Tools to handle small RNA sequences

> THIS REPO IS UNDER ACTIVE DEVELOPMENT.
